==> haskell-optics-extra-0.4.2.1-136-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-7IheOf8bgEX8jhFMAffq4o
key:                  optics-extra-0.4.2.1-7IheOf8bgEX8jhFMAffq4o
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  520ab0d1dc72f53770aaa89953eb8ad8
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.2.8/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-7IheOf8bgEX8jhFMAffq4o
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-BiMdM8DAZvpBwJziK8reqF
    indexed-profunctors-0.1.1.1-75fifDzrRPoIEkrRsA78TU
    indexed-traversable-instances-0.1.2-KVuMkmxoxJVIHXMWaU7AJu
    mtl-2.2.2 optics-core-0.4.1.1-DJ0CfRmYKqO3br20K1DHJY text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C
    vector-0.13.1.0-L0sJ9rsFoTeKCVYCfA24Gj

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-extra-0.4.2.1-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-86lHGDlvGiMGGfgqz50Aff
key:                  optics-extra-0.4.2.1-86lHGDlvGiMGGfgqz50Aff
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  995026ba2cddbd3cd5ec18463edd2b42
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.2.8/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-86lHGDlvGiMGGfgqz50Aff
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    indexed-profunctors-0.1.1.1-75fifDzrRPoIEkrRsA78TU
    indexed-traversable-instances-0.1.2-DJYPkjQPjav9oKGxdyOvVV
    mtl-2.2.2 optics-core-0.4.1.1-FZC5SrLYkAHJY9DVqdlmJO text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
